/*////////////////////////////////////////////////////////////////////////////
    PROJECT:    System Manager
    COPYRIGHT    2011 Dean J. Boman

    FILE:       HWP BOMAN.h
    AUTHOR:     Dean J. Boman

    OVERVIEW:
       Hardware specific configuration definations.  Based on the System_manager board design.


    REVISION HISTORY:

	Oct. 25. 2011	Initial development 
	Nov. 18, 2011	Adjust fuses and clock frequency




*/////////////////////////////////////////////////////////////////////////////
#ifndef HARDWARE_PROFILE_H
#define HARDWARE_PROFILE_H

#include "Compiler.h"

// Clock frequency values.  The on board osc is 10 MHz with a 4X in the PLL gives the 40 MHz clock
// These directly influence timed events using the Tick module.  They also are used for UART and SPI baud rate generation.
#define GetSystemClock()		(40000000ul)			// Hz
#define GetInstructionClock()	(GetSystemClock()/4)	// Normally GetSystemClock()/4 for PIC18, GetSystemClock()/2 for PIC24/dsPIC, and GetSystemClock()/1 for PIC32.  Might need changing if using Doze modes.
#define GetPeripheralClock()	(GetSystemClock()/4)	// Normally GetSystemClock()/4 for PIC18, GetSystemClock()/2 for PIC24/dsPIC, and GetSystemClock()/1 for PIC32.  Divisor may be different if using a PIC32 since it's configurable.

//Timer1 is configured to generate an interrup once every 50 msec for time keeping purposes.
//The system clock is 40 MHz and the timer uses a /8 so the timer frequency is 1.25 MHz.
//We preload the timer with 3036 so it will roll over once per 50 msec.
#define TIMER1_HIGH     	0x0b
#define TIMER1_LOW			0xdc

// Hardware I/O pin mappings
//
// LEDs
#define ONE_SEC_LED_TRIS			(TRISBbits.TRISB5)	// Ref b5
#define ONE_SEC_LED					(PORTBbits.RB5)
//#define ONE_SEC_LED					(LATBbits.LATB5)

//PC Relay which controls the AC power to the PC
#define PC_RELAY_TRIS				(TRISBbits.TRISB1)	// Ref b1
#define PC_RELAY					(LATBbits.LATB1)

//PC ON/OFF switch
#define PC_SW_TRIS					(TRISAbits.TRISA4)	// Ref a4
#define PC_SW						(LATAbits.LATA4)

//Air conditioning relay
#define AC_RELAY_TRIS				(TRISBbits.TRISB0)	// Ref b0
#define AC_RELAY					(LATBbits.LATB0)

//Temperature sensor interface
#define TSENSE_SPI_CLK_TRIS			(TRISCbits.TRISC1)	// Ref c1
#define TSENSE_SPI_CLK				(LATCbits.LATC1)
#define TSENSE_SPI_DATA_TRIS		(TRISCbits.TRISC2)	// Ref c2
#define TSENSE_SPI_DATA				(PORTCbits.RC2)
#define TSENSE_SPI_LOCAL_CS_TRIS	(TRISAbits.TRISA5)	// Ref a5
#define TSENSE_SPI_LOCAL_CS			(LATAbits.LATA5)
#define TSENSE_SPI_REMOTE_CS_TRIS	(TRISCbits.TRISC0)	// Ref c0
#define TSENSE_SPI_REMOTE_CS		(LATCbits.LATC0)


// ENC28J60 I/O pins
//#define ENC_RST_TRIS		(TRISDbits.TRISD2)	// Not connected by default
//#define ENC_RST_IO			(LATDbits.LATD2)
#define ENC_CS_TRIS			(TRISBbits.TRISB3)
#define ENC_CS_IO			(LATBbits.LATB3)
#define ENC_SCK_TRIS		(TRISCbits.TRISC3)
#define ENC_SDI_TRIS		(TRISCbits.TRISC4)			//Data from controller chip
#define ENC_SDO_TRIS		(TRISCbits.TRISC5)			//Data to controller chip
#define ENC_SPI_IF			(PIR1bits.SSPIF)
#define ENC_SSPBUF			(SSPBUF)
#define ENC_SPISTAT			(SSPSTAT)
#define ENC_SPISTATbits		(SSPSTATbits)
#define ENC_SPICON1			(SSPCON1)
#define ENC_SPICON1bits		(SSPCON1bits)
#define ENC_SPICON2			(SSPCON2)



// 25LC256 I/O pins
#define EEPROM_CS_TRIS		(TRISBbits.TRISB4)
#define EEPROM_CS_IO		(LATBbits.LATB4)
#define EEPROM_SCK_TRIS		(TRISCbits.TRISC3)
#define EEPROM_SDI_TRIS		(TRISCbits.TRISC4)			//Data from EEPROM
#define EEPROM_SDO_TRIS		(TRISCbits.TRISC5)			//Data to EEPROM
#define EEPROM_SPI_IF		(PIR1bits.SSPIF)
#define EEPROM_SSPBUF		(SSPBUF)
#define EEPROM_SPICON1		(SSPCON1)
#define EEPROM_SPICON1bits	(SSPCON1bits)
#define EEPROM_SPICON2		(SSPCON2)
#define EEPROM_SPISTAT		(SSPSTAT)
#define EEPROM_SPISTATbits	(SSPSTATbits)



// UART mapping functions for consistent API names across 8-bit and 16 or 
// 32 bit compilers.  For simplicity, everything will use "UART" instead 
// of USART/EUSART/etc.
#define BusyUART()			BusyUSART()
#define CloseUART()			CloseUSART()
#define ConfigIntUART(a)	ConfigIntUSART(a)
#define DataRdyUART()		DataRdyUSART()
#define OpenUART(a,b,c)		OpenUSART(a,b,c)
#define ReadUART()			ReadUSART()
#define WriteUART(a)		WriteUSART(a)
#define getsUART(a,b,c)		getsUSART(b,a)
#define putsUART(a)			putsUSART(a)
#define getcUART()			ReadUSART()
#define putcUART(a)			WriteUSART(a)
#define putrsUART(a)		putrsUSART((far rom char*)a)

#endif // #ifndef HARDWARE_PROFILE_H
