/*////////////////////////////////////////////////////////////////////////////
    PROJECT:    Energy monitoring system
    COPYRIGHT    2011, 2012 Dean J. Boman

    FILE:       HWP BOMAN.h
    AUTHOR:     Dean J. Boman

    OVERVIEW:
       Hardware specific configuration definations.  Based on the System_manager board design.


    REVISION HISTORY:

	Oct. 25. 2011	Initial development 
	Nov. 18, 2011	Adjust fuses and clock frequency
	March 10, 2012	Update for EMS



*/////////////////////////////////////////////////////////////////////////////
#ifndef HARDWARE_PROFILE_H
#define HARDWARE_PROFILE_H

#include "Compiler.h"



// Clock frequency values.  The on board osc is 8 MHz with an input divider of 2 followed by
// a PLL multiplier of 20 and a PLL output divider of 1 which gives a system clock of 80 MHz




// These directly influence timed events using the Tick module.  They also are used for UART and SPI baud rate generation.
#define GetSystemClock()		(80000000L)			// Hz
#define GetInstructionClock()	GetSystemClock()
#define GetPeripheralClock()	(GetSystemClock()/(1 << OSCCONbits.PBDIV))	

//Timer2 is configured to generate an interrup once every 99.8 usec for time keeping purposes.
//The peripheral clock is 80 MHz and the timer uses a /16 so the timer frequency is 5 MHz.
//We preload the timer with 498 so it will roll over once per 50 msec.
#define TIMER2_MATCH     	0x01f2


// Hardware I/O pin mappings
//
// LEDs
#define ONE_SEC_LED_TRIS			(TRISAbits.TRISA0)	// Ref a0
#define ONE_SEC_LED					(PORTAbits.RA0)

//Analog Mux Select
#define MUX_SELECT_S0_TRIS			TRISGCLR= 0x4000
#define MUX_SELECT_S1_TRIS			TRISGCLR = 0x1000
#define MUX_SELECT_S2_TRIS			TRISGCLR = 0x2000

#define MUX_SELECT_0				PORTG = ((PORTG & 0x8fff) |0x0000)
#define MUX_SELECT_1				PORTG = ((PORTG & 0x8fff) |0x4000)
#define MUX_SELECT_2				PORTG = ((PORTG & 0x8fff) |0x1000)
#define MUX_SELECT_3				PORTG = ((PORTG & 0x8fff) |0x5000)
#define MUX_SELECT_4				PORTG = ((PORTG & 0x8fff) |0x2000)
#define MUX_SELECT_5				PORTG = ((PORTG & 0x8fff) |0x6000)
#define MUX_SELECT_6				PORTG = ((PORTG & 0x8fff) |0x3000)
#define MUX_SELECT_7				PORTG = ((PORTG & 0x8fff) |0x7000)



// ENC28J60 I/O pins
//#define ENC_RST_TRIS		(TRISDbits.TRISD2)	// Not connected by default
//#define ENC_RST_IO			(LATDbits.LATD2)
#define ENC_CS_TRIS			(TRISDbits.TRISD5)
#define ENC_CS_IO			(LATDbits.LATD5)
#define ENC_SCK_TRIS		(TRISDbits.TRISD10)
#define ENC_SDI_TRIS		(TRISCbits.TRISC4)			//Data from controller chip
#define ENC_SDO_TRIS		(TRISDbits.TRISD0)			//Data to controller chip
#define ENC_SSPBUF			(SPI1BUF)
#define ENC_SPISTAT			(SPI1STAT)
#define ENC_SPISTATbits		(SPI1STATbits)
#define ENC_SPICON1			(SPI1CON)
#define ENC_SPICON1bits		(SPI1CONbits)
#define ENC_SPICON2			(SPI1CON2)
#define ENC_SPIBRG			(SPI1BRG)



// UART mapping functions for consistent API names across 8-bit and 16 or 
// 32 bit compilers.  For simplicity, everything will use "UART" instead 
// of USART/EUSART/etc.
#define BusyUART()			BusyUSART()
#define CloseUART()			CloseUSART()
#define ConfigIntUART(a)	ConfigIntUSART(a)
#define DataRdyUART()		DataRdyUSART()
#define OpenUART(a,b,c)		OpenUSART(a,b,c)
#define ReadUART()			ReadUSART()
#define WriteUART(a)		WriteUSART(a)
#define getsUART(a,b,c)		getsUSART(b,a)
#define putsUART(a)			putsUSART(a)
#define getcUART()			ReadUSART()
#define putcUART(a)			WriteUSART(a)
#define putrsUART(a)		putrsUSART((far rom char*)a)


/*
The mapping between the current measurement channels and the physical implementation
is shown below:

~Chan0~		Kitchen lights/plugs
~Chan1~		Dining Room & Great Room lights/plugs
~Chan2~		Breakfast Nook lights/plugs
~Chan3~		Dining Room North & Porch
~Chan4~		Quilt Room & Utility Room lights
~Chan5~		Barn Sub-panel
~Chan6~		Master Bedroom lights/plugs
~Chan7~		Master Bath and Closet lights
~Chan8~		Hall, Den, Guest Room lights
~Chan9~		Great Room North/West plugs
~Chan10~	Dish Washer & Disposal
~Chan11~	Refrigerator
~Chan12~	Washer & 2nd Refrigerator
~Chan13~	Freezer and Wiring Closet
~Chan14~	Quilt Room North/West plugs
~Chan15~	Quilt Room South/East plugs
~Chan16~	Main Bath GFCI plugs
~Chan17~	Office plugs
~Chan18~	Master Bath GFCI plugs
~Chan19~	Garage East plugs
~Chan20~	Garage West plugs
~Chan21~	Kitchen East plugs
~Chan22~	Hot Tub
~Chan23~	Kitchen Island plugs
~Chan24~	Air Conditioner - South  (North AH)
~Chan25~	Air Conditioner - North  (South AC)
~Chan26~	Hot Water tank
~Chan27~	Dryer
~Chan28~	Air Handler/Heater - North (North AC)
~Chan29~	Air Handler/Heater - South
~Chan30~	Oven
~Chan31~	Cook Top
*/



//Current measurement channel bias cal factors
//There are determined to shorting out the current sensor and reading the ADC value
//As a future enhancement a FET could be added across the sensor to automatically calibrate
//on a periodic basis
#define CHAN0_CAL	483
#define CHAN1_CAL	481
#define CHAN2_CAL	484
#define CHAN3_CAL	481
#define CHAN4_CAL	483
#define CHAN5_CAL	481
#define CHAN6_CAL	481
#define CHAN7_CAL	483
#define CHAN8_CAL	483
#define CHAN9_CAL	482
#define CHAN10_CAL	483
#define CHAN11_CAL	483
#define CHAN12_CAL	483
#define CHAN13_CAL	481
#define CHAN14_CAL	483
#define CHAN15_CAL	483
#define CHAN16_CAL	483
#define CHAN17_CAL	479
#define CHAN18_CAL	485
#define CHAN19_CAL	484
#define CHAN20_CAL	483
#define CHAN21_CAL	482
#define CHAN22_CAL	483
#define CHAN23_CAL	481
#define CHAN24_CAL	483
#define CHAN25_CAL	482
#define CHAN26_CAL	479
#define CHAN27_CAL	479
#define CHAN28_CAL	479
#define CHAN29_CAL	477
#define CHAN30_CAL	483
#define CHAN31_CAL	483


//Current measurement channel gain factors.  This factor includes the current sensor, load resistor,
//active filter gain, and the ADC gain.  These factors are in terms of A/quant

#define CHAN0_GAIN		0.04105
#define CHAN1_GAIN		0.04105
#define CHAN2_GAIN		0.04105
#define CHAN3_GAIN		0.04105
#define CHAN4_GAIN		0.04105
#define CHAN5_GAIN		0.04105
#define CHAN6_GAIN		0.04105
#define CHAN7_GAIN		0.04105
#define CHAN8_GAIN		0.04105
#define CHAN9_GAIN		0.04105
#define CHAN10_GAIN		0.05585
#define CHAN11_GAIN		0.05585
#define CHAN12_GAIN		0.05585
#define CHAN13_GAIN		0.05585
#define CHAN14_GAIN		0.05585
#define CHAN15_GAIN		0.05585
#define CHAN16_GAIN		0.05585
#define CHAN17_GAIN		0.05585
#define CHAN18_GAIN		0.05585
#define CHAN19_GAIN		0.05585
#define CHAN20_GAIN		0.05585
#define CHAN21_GAIN		0.05585
#define CHAN22_GAIN		0.05585
#define CHAN23_GAIN		0.05585
#define CHAN24_GAIN		0.05585
#define CHAN25_GAIN		0.05585
#define CHAN26_GAIN		0.06945
#define CHAN27_GAIN		0.16416
#define CHAN28_GAIN		0.13890
#define CHAN29_GAIN		0.13890
#define CHAN30_GAIN		0.05585
#define CHAN31_GAIN		0.05585



#endif // #ifndef HARDWARE_PROFILE_H
