/*////////////////////////////////////////////////////////////////////////////
    PROJECT:    Energy Monitoring System
    COPYRIGHT    2011, 2012 Dean J. Boman

    FILE:       Main.h
    AUTHOR:     Dean J. Boman

    OVERVIEW:
        Implementation of the main routine for the Energy Monitoring system.  This routine calls
		and configures various functions from the Microchip TCP/IP stack version 5.36.2.
		In addition it implements application specific functions for the Energy Monitoring System.

		This routine is based on the Microchip maindemo.c function will all the unused
		defines, ifdefs, and function calls removed for a cleaner implementation.



    REVISION HISTORY:

	Oct. 12. 2011	Initial development based on stack version 5.36.2
	Dec. 10, 2011	Ported stack from System Monitor to Energy Monitoring System.  Updated for PIC32.
	March 10, 2012	Updated with EMS functionality
	March 18, 2012	Updated based on hardware/software integration



*/////////////////////////////////////////////////////////////////////////////
#ifndef _MAIN_H
#define _MAIN_H

#include "typedef.h"
#include "Time_conversion.h"


void SaveAppConfig(const APP_CONFIG *AppConfig);


// External Prototypes



// Define a header structure for validating the AppConfig data structure in EEPROM/Flash
typedef struct
{
	unsigned short wConfigurationLength;	// Number of bytes saved in EEPROM/Flash (sizeof(APP_CONFIG))
	unsigned short wOriginalChecksum;		// Checksum of the original AppConfig defaults as loaded from ROM (to detect when to wipe the EEPROM/Flash record of AppConfig due to a stack change, such as when switching from Ethernet to Wi-Fi)
	unsigned short wCurrentChecksum;		// Checksum of the current EEPROM/Flash data.  This protects against using corrupt values if power failure occurs while writing them and helps detect coding errors in which some other task writes to the EEPROM in the AppConfig area.
} NVM_VALIDATION_STRUCT;





#endif // _MAIN_H
