/*********************************************************************
 *
 *  Application to Demo HTTP2 Server
 *  Support for HTTP2 module in Microchip TCP/IP Stack
 *	 -Implements the application 
 *	 -Reference: RFC 1002
 *
 *********************************************************************
 * FileName:        CustomHTTPApp.c
 * Dependencies:    TCP/IP stack
 * Processor:       PIC18, PIC24F, PIC24H, dsPIC30F, dsPIC33F, PIC32
 * Compiler:        Microchip C32 v1.05 or higher
 *					Microchip C30 v3.12 or higher
 *					Microchip C18 v3.30 or higher
 *					HI-TECH PICC-18 PRO 9.63PL2 or higher
 * Company:         Microchip Technology, Inc.
 *
 * Software License Agreement
 *
 * Copyright (C) 2002-2010 Microchip Technology Inc.  All rights
 * reserved.
 *
 * Microchip licenses to you the right to use, modify, copy, and
 * distribute:
 * (i)  the Software when embedded on a Microchip microcontroller or
 *      digital signal controller product ("Device") which is
 *      integrated into Licensee's product; or
 * (ii) ONLY the Software driver source files ENC28J60.c, ENC28J60.h,
 *		ENCX24J600.c and ENCX24J600.h ported to a non-Microchip device
 *		used in conjunction with a Microchip ethernet controller for
 *		the sole purpose of interfacing with the ethernet controller.
 *
 * You should refer to the license agreement accompanying this
 * Software for additional information regarding your rights and
 * obligations.
 *
 * THE SOFTWARE AND DOCUMENTATION ARE PROVIDED "AS IS" WITHOUT
 * WARRANTY OF ANY KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT
 * LIMITATION, ANY WARRANTY OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT SHALL
 * MICROCHIP BE LIABLE FOR ANY INCIDENTAL, SPECIAL, INDIRECT OR
 * CONSEQUENTIAL DAMAGES, LOST PROFITS OR LOST DATA, COST OF
 * PROCUREMENT OF SUBSTITUTE GOODS, TECHNOLOGY OR SERVICES, ANY CLAIMS
 * BY THIRD PARTIES (INCLUDING BUT NOT LIMITED TO ANY DEFENSE
 * THEREOF), ANY CLAIMS FOR INDEMNITY OR CONTRIBUTION, OR OTHER
 * SIMILAR COSTS, WHETHER ASSERTED ON THE BASIS OF CONTRACT, TORT
 * (INCLUDING NEGLIGENCE), BREACH OF WARRANTY, OR OTHERWISE.
 *
 *
 * Author               Date    Comment
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * Elliott Wood     	6/18/07	Original
 ********************************************************************/
#define __CUSTOMHTTPAPP_C

#include "TCPIPConfig.h"

#if defined(STACK_USE_HTTP2_SERVER)

#include "TCPIP Stack/TCPIP.h"
#include "Main.h"
#include "typedef.h"
#include "Time_conversion.h"

/****************************************************************************
  Section:
	Function Prototypes and Memory Globalizers
  ***************************************************************************/

extern TIME Time;
extern ChannelRMSCurrent[];
uint8 VarString[50];

// Sticky status message variable.
// This is used to indicated whether or not the previous POST operation was 
// successful.  The application uses these to store status messages when a 
// POST operation redirects.  This lets the application provide status messages
// after a redirect, when connection instance data has already been lost.
static BOOL lastSuccess = FALSE;

// Stick status message variable.  See lastSuccess for details.
static BOOL lastFailure = FALSE;

/****************************************************************************
  Section:
	Authorization Handlers
  ***************************************************************************/
  
  
/*****************************************************************************
  Function:
	BYTE HTTPNeedsAuth(BYTE* cFile)
	
  Internal:
  	See documentation in the TCP/IP Stack API or HTTP2.h for details.
  ***************************************************************************/
#if defined(HTTP_USE_AUTHENTICATION)
BYTE HTTPNeedsAuth(BYTE* cFile)
{
	// If the filename begins with the folder "protect", then require auth
	if(memcmppgm2ram(cFile, (ROM void*)"protect", 7) == 0)
		return 0x00;		// Authentication will be needed later

	// If the filename begins with the folder "snmp", then require auth
	if(memcmppgm2ram(cFile, (ROM void*)"snmp", 4) == 0)
		return 0x00;		// Authentication will be needed later

	#if defined(HTTP_MPFS_UPLOAD_REQUIRES_AUTH)
	if(memcmppgm2ram(cFile, (ROM void*)"mpfsupload", 10) == 0)
		return 0x00;
	#endif

	// You can match additional strings here to password protect other files.
	// You could switch this and exclude files from authentication.
	// You could also always return 0x00 to require auth for all files.
	// You can return different values (0x00 to 0x79) to track "realms" for below.

	return 0x80;			// No authentication required
}
#endif

/*****************************************************************************
  Function:
	BYTE HTTPCheckAuth(BYTE* cUser, BYTE* cPass)
	
  Internal:
  	See documentation in the TCP/IP Stack API or HTTP2.h for details.
  ***************************************************************************/
#if defined(HTTP_USE_AUTHENTICATION)
BYTE HTTPCheckAuth(BYTE* cUser, BYTE* cPass)
{
	if(strcmppgm2ram((char *)cUser,(ROM char *)"admin") == 0
		&& strcmppgm2ram((char *)cPass, (ROM char *)"microchip") == 0)
		return 0x80;		// We accept this combination
	
	// You can add additional user/pass combos here.
	// If you return specific "realm" values above, you can base this 
	//   decision on what specific file or folder is being accessed.
	// You could return different values (0x80 to 0xff) to indicate 
	//   various users or groups, and base future processing decisions
	//   in HTTPExecuteGet/Post or HTTPPrint callbacks on this value.
	
	return 0x00;			// Provided user/pass is invalid
}
#endif

/****************************************************************************
  Section:
	GET Form Handlers
  ***************************************************************************/
  
  
  
/*****************************************************************************
  Function:
	HTTP_IO_RESULT HTTPExecuteGet(void)
	
  Internal:
  	See documentation in the TCP/IP Stack API or HTTP2.h for details.
  ***************************************************************************/
HTTP_IO_RESULT HTTPExecuteGet(void)
{			
		
	return HTTP_IO_DONE;
}


/****************************************************************************
  Section:
	POST Form Handlers
  ***************************************************************************/



/*****************************************************************************
  Function:
	HTTP_IO_RESULT HTTPExecutePost(void)
	
  Internal:
  	See documentation in the TCP/IP Stack API or HTTP2.h for details.
  ***************************************************************************/
HTTP_IO_RESULT HTTPExecutePost(void)
{

	// Resolve which function to use and pass along
//	BYTE filename[20];
	
	// Load the file name
	// Make sure BYTE filename[] above is large enough for your longest name
//	MPFSGetFilename(curHTTP.file, filename, sizeof(filename));
	


//	return HTTP_IO_DONE;

}




/****************************************************************************
  Section:
	Dynamic Variable Callback Functions
  ***************************************************************************/
  
//The following functions are requred to update the web page with dynamic data


void HTTPPrint_System_time(void)
{
	sprintf(VarString,"%02u/%02u/%02u %02u:%02u:%02u",Time.Month,Time.Day,Time.Year,Time.Hour,Time.Minute,Time.Second);
	TCPPutString(sktHTTP,VarString);	
}

void HTTPPrint_Chan0(void)
{
	sprintf(VarString,"%4.2f",ChannelRMSCurrent[0]);
	TCPPutString(sktHTTP,VarString);		
}	

void HTTPPrint_Chan16(void)
{
	sprintf(VarString,"%4.2f",ChannelRMSCurrent[16]);
	TCPPutString(sktHTTP,VarString);		
}

void HTTPPrint_Chan1(void)
{
	sprintf(VarString,"%4.2f",ChannelRMSCurrent[1]);
	TCPPutString(sktHTTP,VarString);		
}

void HTTPPrint_Chan17(void)
{
	sprintf(VarString,"%4.2f",ChannelRMSCurrent[17]);
	TCPPutString(sktHTTP,VarString);		
}

void HTTPPrint_Chan2(void)
{
	sprintf(VarString,"%4.2f",ChannelRMSCurrent[2]);
	TCPPutString(sktHTTP,VarString);		
}

void HTTPPrint_Chan18(void)
{
	sprintf(VarString,"%4.2f",ChannelRMSCurrent[18]);
	TCPPutString(sktHTTP,VarString);		
}

void HTTPPrint_Chan3(void)
{
	sprintf(VarString,"%4.2f",ChannelRMSCurrent[3]);
	TCPPutString(sktHTTP,VarString);		
}

void HTTPPrint_Chan19(void)
{
	sprintf(VarString,"%4.2f",ChannelRMSCurrent[19]);
	TCPPutString(sktHTTP,VarString);		
}

void HTTPPrint_Chan4(void)
{
	sprintf(VarString,"%4.2f",ChannelRMSCurrent[4]);
	TCPPutString(sktHTTP,VarString);		
}

void HTTPPrint_Chan20(void)
{
	sprintf(VarString,"%4.2f",ChannelRMSCurrent[20]);
	TCPPutString(sktHTTP,VarString);		
}

void HTTPPrint_Chan5(void)
{
	sprintf(VarString,"%4.2f",ChannelRMSCurrent[5]);
	TCPPutString(sktHTTP,VarString);		
}

void HTTPPrint_Chan21(void)
{
	sprintf(VarString,"%4.2f",ChannelRMSCurrent[21]);
	TCPPutString(sktHTTP,VarString);		
}

void HTTPPrint_Chan6(void)
{
	sprintf(VarString,"%4.2f",ChannelRMSCurrent[6]);
	TCPPutString(sktHTTP,VarString);		
}

void HTTPPrint_Chan22(void)
{
	sprintf(VarString,"%4.2f",ChannelRMSCurrent[22]);
	TCPPutString(sktHTTP,VarString);		
}

void HTTPPrint_Chan7(void)
{
	sprintf(VarString,"%4.2f",ChannelRMSCurrent[7]);
	TCPPutString(sktHTTP,VarString);		
}

void HTTPPrint_Chan23(void)
{
	sprintf(VarString,"%4.2f",ChannelRMSCurrent[23]);
	TCPPutString(sktHTTP,VarString);		
}

void HTTPPrint_Chan8(void)
{
	sprintf(VarString,"%4.2f",ChannelRMSCurrent[8]);
	TCPPutString(sktHTTP,VarString);		
}

void HTTPPrint_Chan24(void)
{
	sprintf(VarString,"%4.2f",ChannelRMSCurrent[24]);
	TCPPutString(sktHTTP,VarString);		
}

void HTTPPrint_Chan9(void)
{
	sprintf(VarString,"%4.2f",ChannelRMSCurrent[9]);
	TCPPutString(sktHTTP,VarString);		
}

void HTTPPrint_Chan29(void)
{
	sprintf(VarString,"%4.2f",ChannelRMSCurrent[29]);
	TCPPutString(sktHTTP,VarString);		
}

void HTTPPrint_Chan10(void)
{
	sprintf(VarString,"%4.2f",ChannelRMSCurrent[10]);
	TCPPutString(sktHTTP,VarString);		
}

void HTTPPrint_Chan25(void)
{
	sprintf(VarString,"%4.2f",ChannelRMSCurrent[25]);
	TCPPutString(sktHTTP,VarString);		
}

void HTTPPrint_Chan11(void)
{
	sprintf(VarString,"%4.2f",ChannelRMSCurrent[11]);
	TCPPutString(sktHTTP,VarString);		
}

void HTTPPrint_Chan28(void)
{
	sprintf(VarString,"%4.2f",ChannelRMSCurrent[28]);
	TCPPutString(sktHTTP,VarString);		
}

void HTTPPrint_Chan12(void)
{
	sprintf(VarString,"%4.2f",ChannelRMSCurrent[12]);
	TCPPutString(sktHTTP,VarString);		
}

void HTTPPrint_Chan31(void)
{
	sprintf(VarString,"%4.2f",ChannelRMSCurrent[31]);
	TCPPutString(sktHTTP,VarString);		
}

void HTTPPrint_Chan13(void)
{
	sprintf(VarString,"%4.2f",ChannelRMSCurrent[13]);
	TCPPutString(sktHTTP,VarString);		
}

void HTTPPrint_Chan30(void)
{
	sprintf(VarString,"%4.2f",ChannelRMSCurrent[30]);
	TCPPutString(sktHTTP,VarString);		
}

void HTTPPrint_Chan14(void)
{
	sprintf(VarString,"%4.2f",ChannelRMSCurrent[14]);
	TCPPutString(sktHTTP,VarString);		
}

void HTTPPrint_Chan27(void)
{
	sprintf(VarString,"%4.2f",ChannelRMSCurrent[27]);
	TCPPutString(sktHTTP,VarString);		
}

void HTTPPrint_Chan15(void)
{
	sprintf(VarString,"%4.2f",ChannelRMSCurrent[15]);
	TCPPutString(sktHTTP,VarString);		
}

void HTTPPrint_Chan26(void)
{
	sprintf(VarString,"%4.2f",ChannelRMSCurrent[26]);
	TCPPutString(sktHTTP,VarString);		
}



#endif